----------------------------------------------------------------------
-- file:   analysis_result.sql
-- action: alter/create database package for WS CWS
-- usage:  connect as SYSTEM
--         run this script
----------------------------------------------------------------------

set echo on

spool analysis_result.log

alter session set CURRENT_SCHEMA = CWS_DATA;

create or replace
package ANALYSIS_RESULT
is
  procedure ADD_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ANALYSIS_COMMENTS      in  varchar2
  , DETECTION_INDICATOR    in  varchar2
  , DETECTION_PROBABILITY  in  varchar2
  , ERROR_TEXT             out varchar2
  );

  procedure CUT_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ERROR_TEXT             out varchar2
  );

  procedure SET_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ANALYSIS_COMMENTS      in  varchar2
  , DETECTION_INDICATOR    in  varchar2
  , DETECTION_PROBABILITY  in  varchar2
  , ERROR_TEXT             out varchar2
  );
end ANALYSIS_RESULT;
/

show errors

create or replace
package BODY ANALYSIS_RESULT
is
  procedure ADD_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ANALYSIS_COMMENTS      in  varchar2
  , DETECTION_INDICATOR    in  varchar2
  , DETECTION_PROBABILITY  in  varchar2
  , ERROR_TEXT             out varchar2
  )
  is
  begin
    insert into ANALYSIS_RESULTS
     ( APPLICATION_ID
     , LOCATION_ID
     , TIME_STEP
     , ANALYSIS_COMMENTS
     , DETECTION_INDICATOR
     , DETECTION_PROBABILITY
     )
     values
     ( add_result.APPLICATION_ID
     , add_result.LOCATION_ID
     , to_date(add_result.TIME_STEP,'mm/dd/yyyy hh:mi am')
     , add_result.ANALYSIS_COMMENTS
     , add_result.DETECTION_INDICATOR
     , add_result.DETECTION_PROBABILITY
     );

    ERROR_TEXT := null;
  exception
    when DUP_VAL_ON_INDEX then
      ERROR_TEXT := 'analysis result is already on record';
    when others then
      ERROR_TEXT := SQLERRM;
  end ADD_RESULT;

  procedure CUT_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ERROR_TEXT             out varchar2
  )
  is
  begin
    delete from ANALYSIS_RESULTS
     where APPLICATION_ID = cut_result.APPLICATION_ID
     and   LOCATION_ID = cut_result.LOCATION_ID
     and   TIME_STEP = to_date(cut_result.TIME_STEP,'mm/dd/yyyy hh:mi am');

    ERROR_TEXT := null;
  exception
    when NO_DATA_FOUND then
      ERROR_TEXT := 'analysis result is not on record';
    when others then
      ERROR_TEXT := SQLERRM;
  end CUT_RESULT;

  procedure SET_RESULT
  ( APPLICATION_ID         in  varchar2
  , LOCATION_ID            in  varchar2
  , TIME_STEP              in  varchar2
  , ANALYSIS_COMMENTS      in  varchar2
  , DETECTION_INDICATOR    in  varchar2
  , DETECTION_PROBABILITY  in  varchar2
  , ERROR_TEXT             out varchar2
  )
  is
  begin
    update ANALYSIS_RESULTS
     set ANALYSIS_COMMENTS     = set_result.ANALYSIS_COMMENTS
       , DETECTION_INDICATOR   = set_result.DETECTION_INDICATOR
       , DETECTION_PROBABILITY = set_result.DETECTION_PROBABILITY
     where APPLICATION_ID = set_result.APPLICATION_ID
     and   LOCATION_ID = set_result.LOCATION_ID
     and   TIME_STEP = to_date(set_result.TIME_STEP,'mm/dd/yyyy hh:mi am');

    ERROR_TEXT := null;
  exception
    when NO_DATA_FOUND then
      ERROR_TEXT := 'analysis result is not on record';
    when others then
      ERROR_TEXT := SQLERRM;
  end SET_RESULT;
end ANALYSIS_RESULT;
/

show errors

spool off
